@@ -67,7 +67,7 @@ QVariant RunnerMatchesModel::data(const QModelIndex &index, int role) const
         }
     } else if (role == Kicker::UrlRole) {
         const QString &runnerId = match.runner()->id();
-        if (runnerId == QLatin1String("baloosearch")) {
+        if (runnerId == QLatin1String("baloosearch") || runnerId == QLatin1String("bookmarks")) {
             return QUrl(match.data().toString());
         } else if (runnerId == QLatin1String("recentdocuments")
                    || runnerId == QLatin1String("services")) {
@@ -155,6 +155,9 @@ bool RunnerMatchesModel::trigger(int row, const QString &actionId, const QVarian
         return true;
     } else if (actionId == QLatin1String("_kicker_jumpListAction")) {
         return KRun::run(argument.toString(), {}, nullptr, service ? service->name() : QString(), service ? service->icon() : QString());
+    } else if (actionId == QLatin1String("_kicker_recentDocument")
+        || actionId == QLatin1String("_kicker_forgetRecentDocuments")) {
+        return Kicker::handleRecentDocumentAction(service, actionId, argument);
     }
 
     if (!actionId.isEmpty()) {
